@@ -9,12 +9,14 @@ import click
 
 from pydistcheck.checks import (
     ALL_CHECKS,
+    _CompiledObjectsDebugSymbolCheck,
     _DistroTooLargeCompressedCheck,
     _DistroTooLargeUnCompressedCheck,
     _FileCountCheck,
     _FilesOnlyDifferByCaseCheck,
     _NonAsciiCharacterCheck,
     _SpacesInPathCheck,
+    _UnexpectedFilesCheck,
 )
 from pydistcheck.config import _Config
 from pydistcheck.distribution_summary import _DistributionSummary
@@ -79,6 +81,28 @@ from pydistcheck.utils import _FileSize
         "  - G = gigabytes"
     ),
 )
+@click.option(
+    "--unexpected-directory-patterns",
+    default=_Config.unexpected_directory_patterns,
+    show_default=True,
+    type=str,
+    help=(
+        "comma-delimited list of patterns matching directories that are not expected "
+        "to be found in the distribution. Patterns should be in the format understood "
+        "by ``fnmatch.fnmatchcase()``. See https://docs.python.org/3/library/fnmatch.html."
+    ),
+)
+@click.option(
+    "--unexpected-file-patterns",
+    default=_Config.unexpected_file_patterns,
+    show_default=True,
+    type=str,
+    help=(
+        "comma-delimited list of patterns matching files that are not expected "
+        "to be found in the distribution. Patterns should be in the format understood "
+        "by ``fnmatch.fnmatchcase()``. See https://docs.python.org/3/library/fnmatch.html."
+    ),
+)
 def check(  # pylint: disable=too-many-arguments
     filepaths: str,
     ignore: str,
@@ -86,6 +110,8 @@ def check(  # pylint: disable=too-many-arguments
     max_allowed_files: int,
     max_allowed_size_compressed: str,
     max_allowed_size_uncompressed: str,
+    unexpected_directory_patterns: str,
+    unexpected_file_patterns: str,
 ) -> None:
     """
     Run the contents of a distribution through a set of checks, and warn about
@@ -100,6 +126,8 @@ def check(  # pylint: disable=too-many-arguments
         "max_allowed_files": max_allowed_files,
         "max_allowed_size_compressed": max_allowed_size_compressed,
         "max_allowed_size_uncompressed": max_allowed_size_uncompressed,
+        "unexpected_directory_patterns": unexpected_directory_patterns,
+        "unexpected_file_patterns": unexpected_file_patterns,
     }
     kwargs_that_differ_from_defaults = {}
     for k, v in kwargs.items():
@@ -118,6 +146,7 @@ def check(  # pylint: disable=too-many-arguments
         sys.exit(1)
 
     checks = [
+        _CompiledObjectsDebugSymbolCheck(),
         _DistroTooLargeCompressedCheck(
             max_allowed_size_bytes=_FileSize.from_string(
                 size_str=config.max_allowed_size_compressed
@@ -131,6 +160,10 @@ def check(  # pylint: disable=too-many-arguments
         _FileCountCheck(max_allowed_files=config.max_allowed_files),
         _FilesOnlyDifferByCaseCheck(),
         _SpacesInPathCheck(),
+        _UnexpectedFilesCheck(
+            unexpected_directory_patterns=unexpected_directory_patterns.split(","),
+            unexpected_file_patterns=unexpected_file_patterns.split(","),
+        ),
         _NonAsciiCharacterCheck(),
     ]
 
@@ -151,7 +184,7 @@ def check(  # pylint: disable=too-many-arguments
         for this_check in checks:
             errors += this_check(distro_summary=summary)
 
-        for i, error_msg in enumerate(errors):
+        for i, error_msg in enumerate(sorted(errors)):
             print(f"{i + 1}. {error_msg}")
 
         num_errors_for_this_file = len(errors)
